@@ -11,7 +11,7 @@ from os.path import join, expandvars, realpath, expanduser
 
 from valuebag import ValueBag
 
-__all__ = ['settings', 'version']
+__all__ = ['settings', 'version', 'config']
 
 #def expand_path(path):
 #    return realpath(expandvars(expanduser(path)))
@@ -51,10 +51,10 @@ config.ROOT_DIR = '$VIRTUAL_ENV/..'  # expand_path('$VIRTUAL_ENV/..')
 if os.environ.has_key('OPT_SITE_DIR'):
     config.SITE_DIR = os.environ['OPT_SITE_DIR'] # expand_path(os.environ['OPT_SITE_DIR'])
 else:
-    config.SITE_DIR = join(settings.ROOT_DIR, 'site')
-config.DATA_DIR = join(settings.SITE_DIR, 'data')
-config.LOGS_DIR = join(settings.SITE_DIR, 'logs')
-config.TMP_DIR = join(settings.SITE_DIR, 'tmp')
+    config.SITE_DIR = join(config.ROOT_DIR, 'site')
+config.DATA_DIR = join(config.SITE_DIR, 'data')
+config.LOGS_DIR = join(config.SITE_DIR, 'logs')
+config.TMP_DIR = join(config.SITE_DIR, 'tmp')
 
 settings = config
 
